@@ -2,16 +2,20 @@
 # -*- coding: utf-8 -*-
 # Copyright (c) 2011-2013 Raphaël Barrois
 
+from __future__ import print_function
+
+from .compat import configparser
+from .compat import urllib_parse
+
 import collections
-import ConfigParser
 import logging
 from logging import handlers as logging_handlers
 import optparse
 import socket
 import time
-import urlparse
 import sys
 
+from . import enums
 from . import lcdrunner
 from . import mpdwrapper
 from . import display_fields
@@ -24,9 +28,11 @@ from . import __version__
 DEFAULT_CONFIG_FILE = '/etc/mpdlcd.conf'
 
 # Display
+
 DEFAULT_REFRESH = 0.5
 DEFAULT_LCD_SCREEN_NAME = 'MPD'
 DEFAULT_PATTERN = ''
+DEFAULT_BACKLIGHT_ON = enums.BACKLIGHT_ON_NEVER
 
 # Connection
 DEFAULT_MPD_PORT = 6600
@@ -49,6 +55,7 @@ BASE_CONFIG = {
         'refresh': ('float', DEFAULT_REFRESH),
         'lcdproc_screen': ('str', DEFAULT_LCD_SCREEN_NAME),
         'pattern': ('str', DEFAULT_PATTERN),
+        'backlight_on': ('str', DEFAULT_BACKLIGHT_ON),
     },
     'connections': {
         'mpd': ('str', 'localhost:%s' % DEFAULT_MPD_PORT),
@@ -112,7 +119,7 @@ def _make_hostport(conn, default_host, default_port, default_user='', default_pa
         (str, int): a (host, port) tuple.
     """
 
-    parsed = urlparse.urlparse('//%s' % conn)
+    parsed = urllib_parse.urlparse('//%s' % conn)
     return Connection(
         parsed.hostname or default_host,
         parsed.port or default_port,
@@ -180,6 +187,8 @@ def run_forever(lcdproc='', mpd='', lcdproc_screen=DEFAULT_LCD_SCREEN_NAME,
         lcdproc_charset=DEFAULT_LCDPROC_CHARSET,
         lcdd_debug=False,
         pattern='', patterns=[],
+        refresh=DEFAULT_REFRESH,
+        backlight_on=DEFAULT_BACKLIGHT_ON,
         retry_attempts=DEFAULT_RETRY_ATTEMPTS,
         retry_wait=DEFAULT_RETRY_WAIT,
         retry_backoff=DEFAULT_RETRY_BACKOFF):
@@ -193,6 +202,8 @@ def run_forever(lcdproc='', mpd='', lcdproc_screen=DEFAULT_LCD_SCREEN_NAME,
         lcdd_debug (bool): whether to enable full LCDd debug
         pattern (str): the pattern to use
         patterns (str list): the patterns to use
+        refresh (float): how often to refresh the display
+        backlight_on (str): the rules for activating backlight
         retry_attempts (int): number of connection attempts
         retry_wait (int): time between connection attempts
         retry_backoff (int): increase to between-attempts delay
@@ -220,8 +231,12 @@ def run_forever(lcdproc='', mpd='', lcdproc_screen=DEFAULT_LCD_SCREEN_NAME,
         charset=lcdproc_charset, retry_config=retry_config)
 
     # Setup connector
-    runner = lcdrunner.MpdRunner(mpd_client, lcd, lcdproc_screen=lcdproc_screen,
-        retry_config=retry_config)
+    runner = lcdrunner.MpdRunner(mpd_client, lcd,
+        lcdproc_screen=lcdproc_screen,
+        refresh_rate=refresh,
+        retry_config=retry_config,
+        backlight_on=backlight_on,
+    )
 
     # Fill pattern
     if pattern:
@@ -280,6 +295,11 @@ def _make_parser():
             help='Register the SCREEN_NAME lcdproc screen for mpd status '
             '(default: %s)' % DEFAULT_LCD_SCREEN_NAME,
             metavar='SCREEN_NAME')
+    group.add_option('--backlight-on', dest='backlight_on',
+            help="Activate backlight always|never|in play mode|in play/pause mode (default: %s)" %
+            DEFAULT_BACKLIGHT_ON,
+            choices=enums.BACKLIGHT_ON_CHOICES,
+            metavar='BACKLIGHT_ON')
 
     # End display options
     parser.add_option_group(group)
@@ -393,12 +413,12 @@ def _setup_logging(syslog=False, syslog_facility=DEFAULT_SYSLOG_FACILITY,
 def _read_config(filename):
     """Read configuration from the given file.
 
-    Parsing is performed through the ConfigParser library.
+    Parsing is performed through the configparser library.
 
     Returns:
         dict: a flattened dict of (option_name, value), using defaults.
     """
-    parser = ConfigParser.RawConfigParser()
+    parser = configparser.RawConfigParser()
     if filename and not parser.read(filename):
         sys.stderr.write(
             u"Unable to open configuration file %s. Use --config='' to disable "
@@ -436,14 +456,14 @@ def _read_config(filename):
 
 
 def _extract_options(config, options, *args):
-    """Extract options values from a ConfigParser, optparse pair.
+    """Extract options values from a configparser, optparse pair.
 
     Options given on command line take precedence over options read in the
     configuration file.
 
     Args:
         config (dict): option values read from a config file through
-            ConfigParser
+            configparser
         options (optparse.Options): optparse 'options' object containing options
             values from the command line
         *args (str tuple): name of the options to extract
@@ -464,12 +484,14 @@ def main(argv):
     options, args = parser.parse_args(argv)
     base_config = _read_config(options.config)
     if options.loglevel == 'debug':
-        print "Base config: %s" % base_config
-        print "With overrides: %s" % _extract_options(base_config, options, *base_config.keys())
+        print("Base config: %s" % base_config)
+        print("With overrides: %s" % _extract_options(base_config, options, *base_config.keys()))
 
     _setup_logging(**_extract_options(base_config, options,
         'syslog', 'syslog_facility', 'syslog_address',
         'logfile', 'loglevel', 'debug'))
     run_forever(**_extract_options(base_config, options,
         'lcdproc', 'mpd', 'lcdproc_charset', 'lcdproc_screen', 'lcdd_debug',
-        'pattern', 'patterns', 'retry_attempts', 'retry_backoff', 'retry_wait'))
+        'refresh', 'backlight_on',
+        'pattern', 'patterns',
+        'retry_attempts', 'retry_backoff', 'retry_wait'))
