@@ -7,6 +7,7 @@
 import collections
 import logging
 
+from . import enums
 from . import utils
 
 logger = logging.getLogger(__name__)
@@ -162,6 +163,34 @@ class StateField(Field):
         widget.set_name(name)
 
 
+class BacklightPseudoField(Field):
+    base_name = 'backlight'
+    target_hooks = ['state']
+
+    def __init__(self, backlight_rule, **kwargs):
+        self.backlight_rule=backlight_rule
+        self._screen = None
+        super(BacklightPseudoField, self).__init__(width=0, **kwargs)
+
+    def add_to_screen(self, screen, left, top):
+        self._screen = screen
+
+    def state_changed(self, widget, new_state):
+        if self.backlight_rule == enums.BACKLIGHT_ON_ALWAYS:
+            backlight_on = True
+        elif self.backlight_rule == enums.BACKLIGHT_ON_NEVER:
+            backlight_on = False
+        elif self.backlight_rule == enums.BACKLIGHT_ON_PLAY:
+            backlight_on = bool(new_state == MPD_PLAY)
+        elif self.backlight_rule == enums.BACKLIGHT_ON_PLAYPAUSE:
+            backlight_on = bool(new_state in [MPD_PLAY, MPD_PAUSE])
+        else:
+            backlight_on = False
+        backlight = 'on' if backlight_on else 'off'
+        logger.debug(u"Setting backlight to %s", backlight)
+        self._screen.set_backlight(backlight)
+
+
 class BaseTimeField(Field):
     target_hooks = ['state', 'elapsed_and_total']
 
@@ -175,7 +204,12 @@ class BaseTimeField(Field):
 
         minutes = seconds / 60
         seconds = seconds % 60
-        return '%02d:%02d' % (minutes, seconds)
+        if minutes > 99:
+            hours = minutes / 60
+            minutes = minutes % 60
+            return '%02dh%02d' % (hours, minutes)
+        else:
+            return '%02d:%02d' % (minutes, seconds)
 
     def add_to_screen(self, screen, left, top):
         return screen.add_string_widget(self.name, self._format_time(None),
@@ -261,7 +295,7 @@ class SamplingField(Field):
 
     def __init__(self, **kwargs):
         width = len(self._format_sampling())
-        super(BitRateField, self).__init__(width=width, **kwargs)
+        super(SamplingField, self).__init__(width=width, **kwargs)
 
     def add_to_screen(self, screen, left, top):
         return screen.add_string_widget(self.name,
