@@ -7,7 +7,9 @@ import time
 
 from lcdproc import server
 
-from mpdlcd import utils
+from . import display_fields
+from . import enums
+from . import utils
 
 
 logger = logging.getLogger(__name__)
@@ -18,17 +20,38 @@ class LcdProcServer(server.Server):
         super(LcdProcServer, self).__init__(hostname, port, *args, **kwargs)
         self.charset = charset
 
+    def _normalize_char(self, char):
+        """Normalize a character according to the LCD charset.
+
+        If the char exists in the charset, don't change it;
+        otherwise, normalize it to ascii.
+
+        Takes a unicode char, returns a unicode char.
+        """
+        try:
+            char.encode(self.charset)
+            return char
+        except UnicodeEncodeError:
+            return (
+                unicodedata.normalize('NFKD', char)
+                .encode('ascii', 'ignore')
+                .decode('ascii')
+            )
+
     def encode(self, text):
         """Helper to handle server-specific text encoding."""
-        return text.encode(self.charset, 'ignore')
+        normalized_text = u''.join(self._normalize_char(char) for char in text)
+        return normalized_text.encode(self.charset)
 
 
 class MpdRunner(utils.AutoRetryCandidate):
-    def __init__(self, client, lcd, lcdproc_screen, *args, **kwargs):
+    def __init__(self, client, lcd, lcdproc_screen, refresh_rate, backlight_on, *args, **kwargs):
         super(MpdRunner, self).__init__(logger=logger, *args, **kwargs)
 
         self.lcd = lcd
         self.lcdproc_screen = lcdproc_screen
+        self.backlight_on = backlight_on
+        self.refresh_rate = refresh_rate
 
         # Make sure we can connect - no need to go further otherwise.
         self._connect_lcd()
@@ -58,9 +81,20 @@ class MpdRunner(utils.AutoRetryCandidate):
         logger.info(u'%s screen added to lcdproc.', screen_name)
         return screen
 
+    def add_pseudo_fields(self):
+        """Add 'pseudo' fields (e.g non-displayed fields) to the display."""
+        fields = []
+        if self.backlight_on != enums.BACKLIGHT_ON_NEVER:
+            fields.append(
+                display_fields.BacklightPseudoField(ref='0', backlight_rule=self.backlight_on)
+            )
+
+        self.pattern.add_pseudo_fields(fields, self.screen)
+
     def setup_pattern(self, patterns, hook_registry):
         self.pattern = patterns[self.screen.height]
         self.pattern.parse()
+        self.add_pseudo_fields()
         self.pattern.add_to_screen(self.screen.width, self.screen)
         self.setup_hooks(hook_registry)
 
@@ -87,7 +121,7 @@ class MpdRunner(utils.AutoRetryCandidate):
         try:
             while True:
                 self.update()
-                time.sleep(0.5)
+                time.sleep(self.refresh_rate)
         except (KeyboardInterrupt, SystemExit):
             pass
         except Exception as e:
